@@ -5,6 +5,7 @@ from __future__ import absolute_import
 from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
 from bitmovin_api_sdk.common.poscheck import poscheck_except
 from bitmovin_api_sdk.encoding.encodings.streams.captions.cea.scc.scc_api import SccApi
+from bitmovin_api_sdk.encoding.encodings.streams.captions.cea.srt.srt_api import SrtApi
 
 
 class CeaApi(BaseApi):
@@ -25,3 +26,10 @@ class CeaApi(BaseApi):
             base_url=base_url,
             logger=logger
         )
+
+        self.srt = SrtApi(
+            api_key=api_key,
+            tenant_org_id=tenant_org_id,
+            base_url=base_url,
+            logger=logger
+        )
