@@ -12,12 +12,14 @@ class StreamsLiveUpdateRequest(object):
     def __init__(self,
                  title=None,
                  description=None,
-                 poster_url=None):
-        # type: (string_types, string_types, string_types) -> None
+                 poster_url=None,
+                 domain_restriction_id=None):
+        # type: (string_types, string_types, string_types, string_types) -> None
 
         self._title = None
         self._description = None
         self._poster_url = None
+        self._domain_restriction_id = None
         self.discriminator = None
 
         if title is not None:
@@ -26,13 +28,16 @@ class StreamsLiveUpdateRequest(object):
             self.description = description
         if poster_url is not None:
             self.poster_url = poster_url
+        if domain_restriction_id is not None:
+            self.domain_restriction_id = domain_restriction_id
 
     @property
     def openapi_types(self):
         types = {
             'title': 'string_types',
             'description': 'string_types',
-            'poster_url': 'string_types'
+            'poster_url': 'string_types',
+            'domain_restriction_id': 'string_types'
         }
 
         return types
@@ -42,7 +47,8 @@ class StreamsLiveUpdateRequest(object):
         attributes = {
             'title': 'title',
             'description': 'description',
-            'poster_url': 'posterUrl'
+            'poster_url': 'posterUrl',
+            'domain_restriction_id': 'domainRestrictionId'
         }
         return attributes
 
@@ -133,6 +139,35 @@ class StreamsLiveUpdateRequest(object):
 
         self._poster_url = poster_url
 
+    @property
+    def domain_restriction_id(self):
+        # type: () -> string_types
+        """Gets the domain_restriction_id of this StreamsLiveUpdateRequest.
+
+        Id of the domain restriction config to use
+
+        :return: The domain_restriction_id of this StreamsLiveUpdateRequest.
+        :rtype: string_types
+        """
+        return self._domain_restriction_id
+
+    @domain_restriction_id.setter
+    def domain_restriction_id(self, domain_restriction_id):
+        # type: (string_types) -> None
+        """Sets the domain_restriction_id of this StreamsLiveUpdateRequest.
+
+        Id of the domain restriction config to use
+
+        :param domain_restriction_id: The domain_restriction_id of this StreamsLiveUpdateRequest.
+        :type: string_types
+        """
+
+        if domain_restriction_id is not None:
+            if not isinstance(domain_restriction_id, string_types):
+                raise TypeError("Invalid type for `domain_restriction_id`, type has to be `string_types`")
+
+        self._domain_restriction_id = domain_restriction_id
+
     def to_dict(self):
         """Returns the model properties as a dict"""
         result = {}
